@@ -2,9 +2,9 @@ package Term::Choose;
 
 use warnings;
 use strict;
-use 5.010001;
+use 5.010000;
 
-our $VERSION = '1.113';
+our $VERSION = '1.114';
 use Exporter 'import';
 our @EXPORT_OK = qw( choose );
 
@@ -81,7 +81,7 @@ sub __set_defaults {
 }
 
 
-sub _next_release__validate_options {
+sub __validate_options {
     my ( $self, $opt ) = @_;
     return if ! defined $opt;
     my $valid = {
@@ -143,91 +143,6 @@ sub _next_release__validate_options {
     }
 }
 
-sub __validate_options {
-    my ( $self, $opt ) = @_;
-    return if ! defined $opt;
-    my $valid = {
-        beep            => '[ 0 1 ]',
-        clear_screen    => '[ 0 1 ]',
-        default         => '[ 0-9 ]+',
-        empty           => '',
-        hide_cursor     => '[ 0 1 ]',
-        index           => '[ 0 1 ]',
-        justify         => '[ 0 1 2 ]',
-        keep            => '[ 1-9 ][ 0-9 ]*',
-        layout          => '[ 0 1 2 3 ]',
-        lf              => 'ARRAY',
-        ll              => '[ 1-9 ][ 0-9 ]*',
-        limit           => '[ 1-9 ][ 0-9 ]*',
-        max_height      => '[ 1-9 ][ 0-9 ]*',
-        max_width       => '[ 1-9 ][ 0-9 ]*',
-        mouse           => '[ 0 1 2 3 4 ]',
-        no_spacebar     => 'ARRAY',
-        order           => '[ 0 1 ]',
-        pad             => '[ 0-9 ]+',
-        pad_one_row     => '[ 0-9 ]+',
-        page            => '[ 0 1 ]',
-        prompt          => '',
-        undef           => '',
-    };
-    my @warn = ();
-    for my $key ( keys %$opt ) {
-        if ( ! exists $valid->{$key} ) {
-            push @warn, "'$key' is not a valid option name";
-            next;
-        }
-        next if ! defined $opt->{$key};
-        if ( $valid->{$key} eq '' && ! ref $opt->{$key} ) {
-            $self->{$key} = $opt->{$key};
-        }
-        elsif ( $key eq 'lf' ) {
-            my $err;
-            if ( ref $opt->{$key} eq 'ARRAY' && @{$opt->{$key}} <= 2 ) {
-                no warnings 'uninitialized';
-                /^[0-9]+\z/ || ++$err && last for @{$opt->{$key}};
-            }
-            else {
-                ++$err;
-            }
-            if ( $err ) {
-                push @warn, "option '$key' : the passed value is not a valid value. Falling back to the default value";
-            }
-            else {
-                $self->{$key} = $opt->{$key};
-            }
-        }
-        elsif ( $key eq 'no_spacebar' ) {
-            my $err;
-            if ( ref $opt->{$key} eq 'ARRAY' ) {
-                no warnings 'uninitialized';
-                /^[0-9]+\z/ || ++$err && last for @{$opt->{$key}};
-            }
-            else {
-                ++$err;
-            }
-            if ( $err ) {
-                push @warn, "option '$key' : the passed value is not a valid value. Falling back to the default value";
-            }
-            else {
-                $self->{$key} = $opt->{$key};
-            }
-        }
-        elsif ( $opt->{$key} =~ m/^$valid->{$key}\z/x ) {
-            $self->{$key} = $opt->{$key};
-        }
-        else {
-            push @warn, "option '$key' : '$opt->{$key}' is not a valid value. Falling back to the default value";
-        }
-    }
-    if ( @warn ) {
-        for my $w ( @warn ) {
-            carp "choose: " . $w;
-        }
-        print "Press a key to continue";
-        my $dummy = <STDIN>;
-    }
-}
-
 
 sub __init_term {
     my ( $self ) = @_;
@@ -279,21 +194,20 @@ sub choose {
     }
     my $self = shift;
     my ( $orig_list_ref, $opt ) = @_;
-    croak "choose: called with " . @_ . " arguments - 0 or 1 arguments expected" if @_ < 1 || @_ > 2;
+    croak "choose: called with " . @_ . " arguments - 1 or 2 arguments expected" if @_ < 1 || @_ > 2;
     croak "choose: the first argument must be an ARRAY reference" if ref $orig_list_ref ne 'ARRAY';
-    if ( ! @$orig_list_ref ) {
-        carp "choose: The first argument refers to an empty list";
-        return;
-    }
     if ( defined $opt ) {
         croak "choose: the (optional) second argument must be a HASH reference" if ref $opt ne 'HASH';
         $self->{backup_opt} = { map{ $_ => $self->{$_} } keys %$opt };
         $self->__validate_options( $opt );
     }
+    if ( ! @$orig_list_ref ) {
+        return;
+    }
     local $\ = undef;
     local $, = undef;
     local $| = 1;
-    $self->{wantarray}  = wantarray;
+    $self->{wantarray} = wantarray;
     $self->__set_defaults();
     if ( $self->{limit} && @$orig_list_ref > $self->{limit} ) {
         $self->{list_to_long} = 1;
@@ -1200,7 +1114,7 @@ Term::Choose - Choose items from a list interactively.
 
 =head1 VERSION
 
-Version 1.113
+Version 1.114
 
 =cut
 
@@ -1240,12 +1154,9 @@ Object-oriented interface:
     my $stopp = Term::Choose->new( { prompt => '' } );
     $stopp->choose( [ 'Press ENTER to continue' ] );               # no choice
 
-=head1 ANNOUNCEMENTS
+=head1 ANNOUNCEMENT
 
-Passing invalid options will become fatal with the next release!
-
-MSWin32: from the next release on L<Win32::Console::ANSI> will be removed! L<Win32::Console> will be used then to
-emulate the escape sequences.
+The option I<limit> will be removed with the next release.
 
 =head1 DESCRIPTION
 
@@ -1347,6 +1258,8 @@ can be closed with C<Return>.
 
 Called in void context C<choose> returns nothing.
 
+If the first argument refers to an empty array, C<choose> returns nothing.
+
 =back
 
 If the items of the list don't fit on the screen, the user can scroll to the next (previous) page(s).
@@ -1590,7 +1503,9 @@ See C<INITIAL_TAB> and C<SUBSEQUENT_TAB> in L<Text::LineFold>.
 
 (default: undefined)
 
-=head2 limit
+=head2 limit - Will be removed with the next release.
+
+This option will be removed with the next release.
 
 Sets the maximal allowed length of the array. (default: undefined)
 
@@ -1730,27 +1645,24 @@ default: "<undef>"
 
 =head2 croak
 
+C<new|config|choose> dies if
+
 =over
 
-=item * If passed an invalid number of arguments C<new|config|choose> dies.
+=item * passed an invalid number of arguments.
 
-=item * If passed an invalid argument C<new|config|choose> dies.
+=item * passed an invalid argument.
+
+=item * passed an invalid option name.
+
+=item * passed an invalid option value.
 
 =back
 
 =head2 carp
 
-Passing invalid options will become fatal with the next release!
-
 =over
 
-=item * If the array referred by the first argument is empty C<choose> warns and returns C<undef> respective an empty
-list.
-
-=item * If an option does not exist C<new|config|choose> warns.
-
-=item * If an option value is not valid C<new|config|choose> warns and uses the default value instead.
-
 =item * If after pressing a key L<Term::ReadKey>::ReadKey returns C<undef> C<choose> warns with C<EOT: $!> and returns
 I<undef> or an empty list in list context.
 
@@ -1760,7 +1672,7 @@ I<undef> or an empty list in list context.
 
 =head2 Perl version
 
-Requires Perl version 5.10.1 or greater.
+Requires Perl version 5.10.0 or greater.
 
 =head2 Modules
 
@@ -1786,10 +1698,6 @@ Additionally, if the OS is MSWin32
 
 L<Win32::Console>
 
-=item
-
-L<Win32::Console::ANSI> (removed with the next release)
-
 =back
 
 are required. Else
@@ -1812,34 +1720,6 @@ C<choose> expects decoded strings as array elements.
 
 For a correct output it is required an appropriate encoding layer for STDOUT matching the terminal's character set.
 
-=head3 MSWin32 operating systems
-
-C<Win32::Console::ANSI> will be removed from the next release on so the following will become obsolete!
-
-C<Term::Choose> uses L<Win32::Console::ANSI> if the operating system is MSWin32.
-
-C<Win32::Console::ANSI> enables the Windows own codepage conversion globally. C<Term::Choose> disables this codepage
-conversion by printing the C<"\e(U"> escape sequence - see C<"\e(U"> in
-L<Win32::Console::ANSI/Escape_sequences_for_Select_Character_Set>.
-
-In a future release of C<Term::Choose> the C<"\e(U"> escape sequence will probably be removed.
-
-You can already gain the C<Win32::Console::ANSI> default (codepage conversion enabled) by setting the environment variable
-TC_KEEP_WINDOWS_MAPPING to a true value (TC_KEEP_WINDOWS_MAPPING will become meaningless if C<"\e(U"> is removed from
-C<Term::Choose>). If you want the automatic conversion you should also ad
-
-    use Win32::Console::ANSI;
-    print "\e(K";
-
-to your code in the case that C<Win32::Console::ANSI> is removed from C<Term::Choose>.
-
-If you want to keep the automatic codepage conversion disabled add
-
-    use Win32::Console::ANSI;
-    print "\e(U";
-
-to your code.
-
 =head2 Monospaced font
 
 It is required a terminal that uses a monospaced font which supports the printed characters.
@@ -1876,9 +1756,7 @@ If the option "clear_screen" is enabled:
 
     "\e[1;1H"   Go to Top Left (Cursor Position)
 
-If the OS is MSWin32 the L<Win32::Console::ANSI> module is used to understand these escape sequences.
-
-C<Win32::Console::ANSI> will be replaced by C<Win32::Console> from the next release on to emulate the escape sequences.
+If the OS is MSWin32 L<Win32::Console> is used, to emulate these escape sequences.
 
 If a I<mouse> mode is enabled
 
