@@ -3,9 +3,9 @@ Term::Choose::Constants;
 
 use warnings;
 use strict;
-use 5.010001;
+use 5.010000;
 
-our $VERSION = '1.113';
+our $VERSION = '1.114';
 
 use Exporter qw( import );
 
@@ -143,37 +143,3 @@ sub VK_DELETE     () { 46 } # unused
 1;
 
 __END__
-
-
-=pod
-
-=encoding UTF-8
-
-=head1 NAME
-
-Term::Choose::Constants - Provides constants for Term::Choose and its plugins.
-
-=head1 VERSION
-
-Version 1.113
-
-=head1 DESCRIPTION
-
-This module is not expected to be directly used by any modules other than L<Term::Choose> and its plugins.
-
-=head1 SEE ALSO
-
-L<Term::Choose>
-
-=head1 AUTHORS
-
-Matthäus Kiem <cuer2s@gmail.com>
-
-=head1 LICENSE AND COPYRIGHT
-
-Copyright (C) 2012-2014 Matthäus Kiem.
-
-This library is free software; you can redistribute it and/or modify it under the same terms as Perl 5.10.0. For
-details, see the full text of the licenses in the file LICENSE.
-
-=cut
