@@ -3,9 +3,9 @@ Term::Choose::Linux;
 
 use warnings;
 use strict;
-use 5.010001;
+use 5.010000;
 
-our $VERSION = '1.113';
+our $VERSION = '1.114';
 
 use Term::ReadKey qw( GetTerminalSize ReadKey ReadMode );
 
@@ -24,7 +24,25 @@ sub __get_key_OS {
     return if ! defined $c1;
     if ( $c1 eq "\e" ) {
         my $c2 = ReadKey( 0.10 );
-        if ( ! defined $c2 ) { return KEY_ESC; } # unused
+           if ( ! defined $c2 ) { return KEY_ESC; } # unused
+        #elsif ( $c3 eq 'A' ) { return VK_UP; }     vt 52
+        #elsif ( $c3 eq 'B' ) { return VK_DOWN; }
+        #elsif ( $c3 eq 'C' ) { return VK_RIGHT; }
+        #elsif ( $c3 eq 'D' ) { return VK_LEFT; }
+        #elsif ( $c3 eq 'H' ) { return VK_HOME; }
+         elsif ( $c2 eq 'O' ) {
+            my $c3 = ReadKey( 0 );
+               if ( $c3 eq 'A' ) { return VK_UP; }
+            elsif ( $c3 eq 'B' ) { return VK_DOWN; }
+            elsif ( $c3 eq 'C' ) { return VK_RIGHT; }
+            elsif ( $c3 eq 'D' ) { return VK_LEFT; }
+            elsif ( $c3 eq 'F' ) { return VK_END; }
+            elsif ( $c3 eq 'H' ) { return VK_HOME; }
+            elsif ( $c3 eq 'Z' ) { return KEY_BTAB; }
+            else {
+                return NEXT_get_key;
+            }
+        }
         elsif ( $c2 eq '[' ) {
             my $c3 = ReadKey( 0 );
                if ( $c3 eq 'A' ) { return VK_UP; }
@@ -213,7 +231,8 @@ sub __get_cursor_position {
 
 sub __clear_screen {
     #my ( $self ) = @_;
-    print "\e[2J\e[1;1H";
+    #print "\e[2J\e[1;1H";
+    print "\e[H\e[J";
 }
 
 
@@ -262,40 +281,3 @@ sub __right {
 1;
 
 __END__
-
-=pod
-
-=encoding UTF-8
-
-=head1 NAME
-
-Term::Choose::Linux - Plugin for Term::Choose.
-
-=head1 VERSION
-
-Version 1.113
-
-=head1 SYNOPSIS
-
-Internal use only.
-
-=head1 DESCRIPTION
-
-This module is not expected to be directly used by any module other than L<Term::Choose>.
-
-=head1 SEE ALSO
-
-L<Term::Choose>
-
-=head1 AUTHORS
-
-Matthäus Kiem <cuer2s@gmail.com>
-
-=head1 LICENSE AND COPYRIGHT
-
-Copyright (C) 2012-2014 Matthäus Kiem.
-
-This library is free software; you can redistribute it and/or modify it under the same terms as Perl 5.10.0. For
-details, see the full text of the licenses in the file LICENSE.
-
-=cut
